@@ -6,7 +6,7 @@ test_that("transect_phys works", {
   test <- transect_phys(test_transect) # manual download
   expect_equal(ncol(test), 6)
   expect_equal(typeof(test[[2]]), "double")
-  expect_equal(names(test)[2], "Frequency")
+  expect_equal(names(test)[2], "frequency")
 
   skip_on_cran()
 
@@ -14,19 +14,19 @@ test_that("transect_phys works", {
   test <- transect_phys(test_raw)
   expect_equal(ncol(test), 6)
   expect_equal(typeof(test[[2]]), "double")
-  expect_equal(names(test)[2], "Frequency")
+  expect_equal(names(test)[2], "frequency")
 
 
   test_raw <- download_transect(7025) # custom database
   test <- transect_phys(test_raw)
   expect_equal(ncol(test), 6)
   expect_equal(typeof(test[[2]]), "double")
-  expect_equal(names(test)[2], "Frequency")
+  expect_equal(names(test)[2], "frequency")
 
   test_raw <- download_transect(6444) # includes omernik
   test <- transect_phys(test_raw)
   expect_equal(ncol(test), 6)
   expect_equal(typeof(test[[2]]), "double")
-  expect_equal(names(test)[2], "Frequency")
+  expect_equal(names(test)[2], "frequency")
 
 })
